Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThilanka <lgtkaushalya@gmail.com>2011-02-28 20:44:44 +0300
committerMarc Delisle <marc@infomarc.info>2011-02-28 20:44:44 +0300
commita994e13c3315f45d88782b51c0f71385074a8251 (patch)
tree06cb2f52a454efbb673b033455d9909f40344dd6 /js/db_search.js
parent896d3bd54eb166f33521c6101272130513599904 (diff)
Ajaxify browse and delete criteria in DB search
Diffstat (limited to 'js/db_search.js')
-rw-r--r--js/db_search.js98
1 files changed, 90 insertions, 8 deletions
diff --git a/js/db_search.js b/js/db_search.js
index 0a82a8f7b2..c581cc3c24 100644
--- a/js/db_search.js
+++ b/js/db_search.js
@@ -14,25 +14,107 @@
* Retrieve result of SQL query
*/
+/** Loads the database search results */
+function loadResult(result_path , table_name , link , ajaxEnable){
+ $(document).ready(function() {
+ if(ajaxEnable)
+ {
+ /** Hides the results shown by the delete criteria */
+ PMA_ajaxShowMessage(PMA_messages['strBrowsing']);
+ $('#sqlqueryform').hide();
+ $('#togglequerybox').hide();
+ /** Load the browse results to the page */
+ $("#table-info").show();
+ $('#table-link').attr({"href" : 'sql.php?'+link }).text(table_name);
+ $('#browse-results').load(result_path + " '"+'#sqlqueryresults' + "'").show();
+ }
+ else
+ {
+ event.preventDefault();
+ }
+ });
+}
+
+/** Delete the selected search results */
+function deleteResult(result_path , msg , ajaxEnable){
+ $(document).ready(function() {
+ /** Hides the results shown by the browse criteria */
+ $("#table-info").hide();
+ $('#browse-results').hide();
+ $('#sqlqueryform').hide();
+ $('#togglequerybox').hide();
+ /** Conformation message for deletion */
+ if(confirm(msg))
+ {
+ if(ajaxEnable)
+ {
+ /** Load the deleted option to the page*/
+ $('#browse-results').load(result_path + " '"+'#result_query' + "'");
+ $('#sqlqueryform').load(result_path + " '"+'#sqlqueryform' + "'");
+ $('#togglequerybox').html(PMA_messages['strHideQueryBox']);
+
+ /** Refresh the the search results after the deletion */
+ document.getElementById('buttonGo'). click();
+ PMA_ajaxShowMessage(PMA_messages['strDeleting']);
+ /** Show the results of the deletion option */
+ $('#browse-results').show();
+ $('#sqlqueryform').show();
+ $('#togglequerybox').show();
+ }
+ else
+ {
+ event.preventDefault();
+ }
+ }
+ });
+}
+
$(document).ready(function() {
/**
* Set a parameter for all Ajax queries made on this page. Don't let the
- * web server serve cached pages
+ * web server serve cached pagesshow
*/
$.ajaxSetup({
cache: 'false'
});
+ /** Hide the table link in the initial search result */
+ $("#table-info").prepend('<img id="table-image" src="./themes/original/img/s_tbl.png" />').hide();
+
+ /** Hide the brose and deleted results in the new search criteria */
+ $('#buttonGo').click(function(){
+ $("#table-info").hide();
+ $('#browse-results').hide();
+ $('#sqlqueryform').hide();
+ $('#togglequerybox').hide();
+ });
/**
* Prepare a div containing a link, otherwise it's incorrectly displayed
* after a couple of clicks
*/
$('<div id="togglesearchformdiv"><a id="togglesearchformlink"></a></div>')
.insertAfter('#db_search_form')
- // don't show it until we have results on-screen
+ /** don't show it until we have results on-screen */
.hide();
+ /** Changing the displayed text according to the hide/show criteria in search form*/
+ $("#togglequerybox").hide();
+ $("#togglequerybox").bind('click', function() {
+ var $link = $(this)
+ $('#sqlqueryform').slideToggle("medium");
+ if ($link.text() == PMA_messages['strHideQueryBox']) {
+ $link.text(PMA_messages['strShowQueryBox']);
+ } else {
+ $link.text(PMA_messages['strHideQueryBox']);
+ }
+ /** avoid default click action */
+ return false;
+ })
+
+ /** don't show it until we have results on-screen */
+
+ /** Changing the displayed text according to the hide/show criteria in search criteria form*/
$('#togglesearchformlink')
.html(PMA_messages['strShowSearchCriteria'])
.bind('click', function() {
@@ -43,7 +125,7 @@ $(document).ready(function() {
} else {
$link.text(PMA_messages['strHideSearchCriteria']);
}
- // avoid default click action
+ /** avoid default click action */
return false;
});
/**
@@ -59,8 +141,8 @@ $(document).ready(function() {
PMA_ajaxShowMessage(PMA_messages['strSearching']);
// jQuery object to reuse
$form = $(this);
-
- // add this hidden field just once
+
+ // add this hidden field just once
if (! $form.find('input:hidden').is('#ajax_request_hidden')) {
$form.append('<input type="hidden" id="ajax_request_hidden" name="ajax_request" value="true" />');
}
@@ -78,12 +160,12 @@ $(document).ready(function() {
// always start with the Show message
.text(PMA_messages['strShowSearchCriteria'])
$('#togglesearchformdiv')
- // now it's time to show the div containing the link
+ // now it's time to show the div containing the link
.show();
} else {
// error message (zero rows)
$("#sqlqueryresults").html(response['message']);
- }
+ }
})
})
}, 'top.frame_content'); // end $(document).ready()
@@ -14,25 +14,107 @@
/**
- * Prepare a div containing a link, otherwise it's incorrectly displayed
+ * Prepare a div containing a link for toggle the seach form, otherwise it's incorrectly displayed
* after a couple of clicks
*/